//
//  OrsonAppDelegate.m
//  Orson
//
//  Created by Mark Meretzky on 11/22/13.
//  Copyright (c) 2013 Mark Meretzky. All rights reserved.
//

#import <MediaPlayer/MediaPlayer.h>	//for MPMoviePlayerViewController
#import "OrsonAppDelegate.h"

#import "TextViewController.h"
#import "StillViewController.h"
#import "ThemeViewController.h"
#import "WebViewController.h"

@implementation OrsonAppDelegate

- (BOOL) application: (UIApplication *) application didFinishLaunchingWithOptions: (NSDictionary *) launchOptions
{
	self.window = [[UIWindow alloc] initWithFrame: [UIScreen mainScreen].bounds];
	// Override point for customization after application launch.
	self.window.backgroundColor = [UIColor blackColor];	//film noir

	NSBundle *bundle = [NSBundle mainBundle];
	url = [NSURL fileURLWithPath: [bundle pathForResource: @"cuckoo" ofType: @"mov"]];

	NSArray *controllers = [NSArray arrayWithObjects:
		[[TextViewController  alloc] initWithNibName: nil bundle: nil],	//text of novel
		[[StillViewController alloc] initWithNibName: nil bundle: nil],	//still photo
		[[MPMoviePlayerViewController alloc] initWithContentURL: url],	//video
		[[ThemeViewController alloc] initWithNibName: nil bundle: nil],	//theme song
		[[WebViewController   alloc] initWithNibName: nil bundle: nil],	//web page
		nil
	];

	/*
	 The third view is not a view at all.  But it has a MPMoviePlayerController.
	 
	"After all, it's not that awful.  But what the fellow says, in Italy for thirty years
	under the Borgias they had warfare, terror, murder, bloodshed, but they produced Michaelangelo,
	Leonardo da Vinci, and the Renaissance.  In Switzerland, they had brotherly love.  They had five
	hundred years of democracy and peace.  And what did that produce?  The cuckoo clock."
	*/

	MPMoviePlayerViewController *moviePlayerViewController = [controllers objectAtIndex: 2];
	moviePlayerViewController.title = @"Video";
	moviePlayerViewController.tabBarItem.image = [UIImage imageNamed: @"Video.png"];

	moviePlayerViewController.moviePlayer.shouldAutoplay = NO;
	currentPlaybackTime = 3.27;
	moviePlayerViewController.moviePlayer.initialPlaybackTime = currentPlaybackTime;
	
	[moviePlayerViewController.moviePlayer prepareToPlay];

	UITabBarController *tabBarController = [[UITabBarController alloc] init];
	tabBarController.delegate = self;
	tabBarController.viewControllers = controllers;
	tabBarController.tabBar.barTintColor = [UIColor blackColor];
	self.window.rootViewController = tabBarController;
	[self.window makeKeyAndVisible];
	return YES;
}

- (void) applicationWillResignActive: (UIApplication *) application
{
	// Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
	// Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
}

- (void) applicationDidEnterBackground: (UIApplication *) application
{
	// Use this method to release shared resources, save user data, invalidate timers, and store enough application state information to restore your application to its current state in case it is terminated later. 
	// If your application supports background execution, this method is called instead of applicationWillTerminate: when the user quits.
}

- (void) applicationWillEnterForeground: (UIApplication *) application
{
	// Called as part of the transition from the background to the inactive state; here you can undo many of the changes made on entering the background.
}

- (void) applicationDidBecomeActive: (UIApplication *) application
{
	// Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
}

- (void) applicationWillTerminate: (UIApplication *) application
{
	// Called when the application is about to terminate. Save data if appropriate. See also applicationDidEnterBackground:.
}

#pragma mark -
#pragma mark Protocol UITabBarControllerDelegate

//Called when user presses tab.

- (void) tabBarController: (UITabBarController *) tabBarController
	didSelectViewController: (UIViewController *) viewController {

	if ([viewController isMemberOfClass: [MPMoviePlayerViewController class]]) {
		MPMoviePlayerController *moviePlayerController =
			((MPMoviePlayerViewController *)viewController).moviePlayer;

		moviePlayerController.contentURL = url;
		moviePlayerController.currentPlaybackTime = currentPlaybackTime;
		[moviePlayerController prepareToPlay];
	}

	else if ([viewController isMemberOfClass: [ThemeViewController class]]) {
		[(ThemeViewController *)viewController play];
	}
}

@end
